==> lhcsmapi-1.4.58.tar.gz: lhcsmapi-1.4.58/lhcsmapi/analysis/RbCircuitQuery.py <==
import pandas as pd

import lhcsmapi
from lhcsmapi.Time import Time
from lhcsmapi.analysis.CircuitQuery import CircuitQuery, get_quench_current, execution_count
from lhcsmapi.analysis.busbar.BusbarResistanceQuery import BusbarResistanceQuery
from lhcsmapi.analysis.dfb.DfbQuery import DfbQuery
from lhcsmapi.analysis.diode.DiodeLeadResistanceQuery import DiodeLeadResistanceQuery
from lhcsmapi.analysis.ee.EeQuery import Ee13kAQuery
from lhcsmapi.analysis.nqps.NqpsQuery import NqpsRbQuery
from lhcsmapi.analysis.pc.PcQuery import Pc13kAQuery
from lhcsmapi.analysis.pic.PicQuery import PicRbQuery
from lhcsmapi.analysis.qds.QdsQuery import QdsRbQuery
from lhcsmapi.analysis.qh.QuenchHeaterQuery import QuenchHeaterQuery
from lhcsmapi.metadata.MappingMetadata import MappingMetadata

from lhcsmapi.reference.Reference import Reference


class RbCircuitQuery(PicRbQuery, Pc13kAQuery, Ee13kAQuery, NqpsRbQuery, QuenchHeaterQuery, BusbarResistanceQuery,
                     DiodeLeadResistanceQuery, QdsRbQuery, DfbQuery, CircuitQuery):
    """Class extending the CircuitQuery class with methods for creation of templates of analysis tables in RB circuits.

    """

    @execution_count()
    def create_report_analysis_template(self, source_timestamp_qds_df: pd.DataFrame,
                                        source_timestamp_nqps_df: pd.DataFrame, timestamp_pic: int,
                                        timestamp_fgc: int, init_file_path: str,
                                        i_meas_df: pd.DataFrame, author: str) -> pd.DataFrame:
        """ Method creating a report analysis template for main dipole circuits

        :param source_timestamp_qds_df: table with QDS PM source and timestamp
        :type source_timestamp_qds_df: pd.DataFrame
        :param source_timestamp_nqps_df: table with QDS PM source and timestamp
        :type source_timestamp_nqps_df: pd.DataFrame
        :param timestamp_pic: unix timestamp of the first PIC event in RQ circuit in nanoseconds
        :type timestamp_pic: int
        :param timestamp_fgc: unix timestamp of an FGC event in RB circuit in nanoseconds
        :type timestamp_fgc: int
        :param init_file_path: path to an init file to read LHCSM-HWC notebooks version
        :type init_file_path: str
        :param i_meas_df: measured power converter current in RB circuit
        :type i_meas_df: pd.DataFrame
        :param author: NICE account name of the analysis author
        :type author: str
        :return: pre-filled pd.DataFrame with a template to be filled further with data from analysis
            of a powering event in main dipole (RB) circuits
        """

        columns = Reference.read_quench_database_columns(circuit_type='RB', table_type='MP3')

        results_table = pd.DataFrame(columns=columns)

        results_table['Position'] = source_timestamp_qds_df['source']
        results_table['Circuit Name'] = self.circuit_name
        results_table['Circuit Family'] = self.circuit_type
        results_table['Period'] = Reference.get_mp3_period(timestamp_fgc)
        results_table['Date (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[0]
        results_table['Time (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[1]

        results_table['nQPS crate name'] = results_table['Position'].apply(
            lambda col: MappingMetadata.get_crate_name_from_magnet_name(self.circuit_type, col))
        results_table['Delta_t(iQPS-PIC)'] = 1e-6 * (source_timestamp_qds_df['timestamp'] - timestamp_pic)
        results_table['I_Q_M'] = results_table['Delta_t(iQPS-PIC)'].apply(
            lambda col: get_quench_current(i_meas_df, 1e-3 * col))
        results_table['Analysis performed by'] = author
        results_table['lhcsmapi version'] = lhcsmapi.__version__
        results_table['lhcsm notebook version'] = lhcsmapi.parse_lhcsmhwc_version(init_file_path)

        if not source_timestamp_nqps_df.empty:
            results_table['Delta_t(nQPS-PIC)'] = 1e-6 * (source_timestamp_nqps_df['timestamp'] - timestamp_pic)
            results_table['timestamp_iqps'] = source_timestamp_qds_df['timestamp']
            source_timestamp_nqps_renamed_df = source_timestamp_nqps_df.rename(
                columns={'source': 'nQPS crate name', 'timestamp': 'timestamp_nqps'})
            results_table = results_table.merge(source_timestamp_nqps_renamed_df[['timestamp_nqps', 'nQPS crate name']],
                                                on='nQPS crate name', how='left').sort_values(
                by='timestamp_iqps').reset_index(drop=True)

        return results_table

==> lhcsmapi-1.5.13.tar.gz: lhcsmapi-1.5.13/lhcsmapi/analysis/RbCircuitQuery.py <==
import pandas as pd

import lhcsmapi
from lhcsmapi.Time import Time
from lhcsmapi.analysis.CircuitQuery import CircuitQuery, get_quench_current, execution_count
from lhcsmapi.analysis.busbar.BusbarResistanceQuery import BusbarResistanceQuery
from lhcsmapi.analysis.dfb.DfbQuery import DfbQuery
from lhcsmapi.analysis.diode.DiodeLeadResistanceQuery import DiodeLeadResistanceQuery
from lhcsmapi.analysis.ee.EeQuery import Ee13kAQuery
from lhcsmapi.analysis.nqps.NqpsQuery import NqpsRbQuery
from lhcsmapi.analysis.pc.PcQuery import Pc13kAQuery
from lhcsmapi.analysis.pic.PicQuery import PicRbQuery
from lhcsmapi.analysis.qds.QdsQuery import QdsRbQuery
from lhcsmapi.analysis.qh.QuenchHeaterQuery import QuenchHeaterQuery
from lhcsmapi.metadata.MappingMetadata import MappingMetadata

from lhcsmapi.reference.Reference import Reference


class RbCircuitQuery(PicRbQuery, Pc13kAQuery, Ee13kAQuery, NqpsRbQuery, QuenchHeaterQuery, BusbarResistanceQuery,
                     DiodeLeadResistanceQuery, QdsRbQuery, DfbQuery, CircuitQuery):
    """Class extending the CircuitQuery class with methods for creation of templates of analysis tables in RB circuits.

    """

    @execution_count()
    def create_report_analysis_template(self, source_timestamp_qds_df: pd.DataFrame,
                                        source_timestamp_nqps_df: pd.DataFrame, timestamp_pic: int,
                                        timestamp_fgc: int, init_file_path: str,
                                        i_meas_df: pd.DataFrame, author: str) -> pd.DataFrame:
        """ Method creating a report analysis template for main dipole circuits

        :param source_timestamp_qds_df: table with QDS PM source and timestamp
        :type source_timestamp_qds_df: pd.DataFrame
        :param source_timestamp_nqps_df: table with QDS PM source and timestamp
        :type source_timestamp_nqps_df: pd.DataFrame
        :param timestamp_pic: unix timestamp of the first PIC event in RQ circuit in nanoseconds
        :type timestamp_pic: int
        :param timestamp_fgc: unix timestamp of an FGC event in RB circuit in nanoseconds
        :type timestamp_fgc: int
        :param init_file_path: path to an init file to read LHCSM-HWC notebooks version
        :type init_file_path: str
        :param i_meas_df: measured power converter current in RB circuit
        :type i_meas_df: pd.DataFrame
        :param author: NICE account name of the analysis author
        :type author: str
        :return: pre-filled pd.DataFrame with a template to be filled further with data from analysis
            of a powering event in main dipole (RB) circuits
        """

        columns = Reference.read_quench_database_columns(circuit_type='RB', table_type='MP3')

        results_table = pd.DataFrame(columns=columns)

        results_table['Position'] = source_timestamp_qds_df['source']
        results_table['Circuit Name'] = self.circuit_name
        results_table['Circuit Family'] = self.circuit_type
        results_table['Period'] = Reference.get_mp3_period(timestamp_fgc)
        results_table['Date (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[0]
        results_table['Time (FGC)'] = Time.to_string_short(timestamp_fgc).split(' ')[1]

        results_table['nQPS crate name'] = results_table['Position'].apply(
            lambda col: MappingMetadata.get_crate_name_from_magnet_name(self.circuit_type, col))
        results_table['Delta_t(iQPS-PIC)'] = 1e-6 * (source_timestamp_qds_df['timestamp'] - timestamp_pic)
        results_table['I_Q_M'] = results_table['Delta_t(iQPS-PIC)'].apply(
            lambda col: get_quench_current(i_meas_df, 1e-3 * col))
        results_table['Analysis performed by'] = author
        results_table['lhcsmapi version'] = lhcsmapi.__version__
        results_table['lhcsm notebook version'] = lhcsmapi.parse_lhcsmhwc_version(init_file_path)

        if not source_timestamp_nqps_df.empty:
            results_table['timestamp_iqps'] = source_timestamp_qds_df['timestamp']
            source_timestamp_nqps_renamed_df = source_timestamp_nqps_df.rename(
                columns={'source': 'nQPS crate name', 'timestamp': 'timestamp_nqps'})
            results_table = results_table.merge(source_timestamp_nqps_renamed_df[['timestamp_nqps', 'nQPS crate name']],
                                                on='nQPS crate name', how='left') \
                .sort_values(by='timestamp_iqps').reset_index(drop=True)
            results_table['Delta_t(nQPS-PIC)'] = 1e-6 * (results_table['timestamp_nqps'] - timestamp_pic)

        return results_table
